==> phoenix_widgets-1.15.0.tar.gz: lib/phoenix_tab_view.dart <==
import 'package:flutter/material.dart';

const defaultPadding = 8.0;

class PhoenixTabView extends StatefulWidget {
  const PhoenixTabView({
    Key? key,
    required this.tabs,
    required this.builder,
    this.currentIndex = 0,
    this.menuBackgroundColor,
    this.menuPadding,
    this.onTabChange,
    this.indicatorColor,
    this.labelColor,
    this.unselectedLabelColor,
    this.tabController,
  }) : super(key: key);

  final int currentIndex;
  final Map<String, String> tabs;
  final Color? menuBackgroundColor;
  final EdgeInsets? menuPadding;
  final void Function(int index)? onTabChange;
  final Color? indicatorColor;
  final Color? labelColor;
  final Color? unselectedLabelColor;
  final Widget Function(BuildContext context, String id) builder;
  final TabController? tabController;

  @override
  State<PhoenixTabView> createState() => _PhoenixTabViewState();
}

class _PhoenixTabViewState extends State<PhoenixTabView>
    with TickerProviderStateMixin {
  TabController? _tabController;
  int _currentIndex = 0;

  @override
  void initState() {
    super.initState();
    if (widget.tabController == null) {
      initTab();
    }
  }

  @override
  void dispose() {
    _tabController?.removeListener(() {});
    super.dispose();
  }

  void initTab() {
    _tabController = TabController(
      length: widget.tabs.keys.length,
      vsync: this,
      initialIndex: widget.currentIndex,
    );
    _tabController?.addListener(() {
      if (widget.onTabChange != null) {
        widget.onTabChange!(_tabController?.index ?? 0);
      }
    });

    setState(() {
      _currentIndex = widget.currentIndex;
    });
  }

  TabController? getTabController() => widget.tabController ?? _tabController;

  @override
  Widget build(BuildContext context) {
    if (widget.tabController == null &&
        widget.tabs.length != _tabController?.length) {
      initTab();
    }

    return DefaultTabController(
      initialIndex: widget.currentIndex,
      length: widget.tabs.length,
      child: Column(
        children: [
          Container(
            color: widget.menuBackgroundColor ?? const Color(0xFFF9F9F9),
            padding:
                widget.menuPadding ?? const EdgeInsets.symmetric(vertical: 16),
            child: TabBar(
              controller: getTabController(),
              onTap: (tabIndex) {},
              isScrollable: true,
              labelPadding: EdgeInsets.zero,
              tabs: widget.tabs.entries
                  .map(
                    (e) => PhoenixTabViewMenuItem(
                      label: e.value,
                      isActive: _currentIndex ==
                          widget.tabs.keys.toList().indexOf(e.key),
                      isFirst: e.key == widget.tabs.keys.first,
                      isLast: e.key == widget.tabs.keys.last,
                    ),
                  )
                  .toList(),
              automaticIndicatorColorAdjustment: false,
              indicatorColor: widget.indicatorColor ?? Colors.transparent,
              labelColor: widget.labelColor ?? const Color(0xff67C1BF),
              unselectedLabelColor:
                  widget.unselectedLabelColor ?? const Color(0xff212124),
              padding: EdgeInsets.zero,
            ),
          ),
          Expanded(
            flex: 9,
            child: TabBarView(
              controller: getTabController(),
              children: widget.tabs.entries
                  .map((e) => widget.builder(context, e.key))
                  .toList(),
            ),
          ),
        ],
      ),
    );
  }
}

class PhoenixTabViewMenuItem extends StatefulWidget {
  const PhoenixTabViewMenuItem({
    Key? key,
    this.isFirst = false,
    this.isActive = false,
    this.isLast = false,
    required this.label,
  }) : super(key: key);

  final bool isFirst;
  final bool isLast;
  final bool isActive;
  final String label;

  @override
  State<PhoenixTabViewMenuItem> createState() => _PhoenixTabViewMenuItemState();
}

class _PhoenixTabViewMenuItemState extends State<PhoenixTabViewMenuItem> {
  final GlobalKey _widgetKey = GlobalKey();

  double _leftPadding = defaultPadding;
  double _rightPadding = defaultPadding;

  void _getWidgetInfo(_) {
    final RenderBox renderBox =
        _widgetKey.currentContext?.findRenderObject() as RenderBox;

    final Size size = renderBox.size;
    final deviceWidth = MediaQuery.of(context).size.width;
    final center = deviceWidth * 0.5;

    if (widget.isFirst) {
      _leftPadding += (center - (size.width / 2));
    }

    if (widget.isLast) {
      _rightPadding += (center - (size.width / 2));
    }

    setState(() {});
  }

  @override
  void initState() {
    WidgetsBinding.instance.addPostFrameCallback(_getWidgetInfo);
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      key: _widgetKey,
      padding: EdgeInsets.only(
        left: _leftPadding,
        right: _rightPadding,
      ),
      child: Text(
        widget.label,
        style: TextStyle(
          fontWeight: widget.isActive ? FontWeight.w500 : FontWeight.w400,
        ),
      ),
    );
  }
}

==> phoenix_widgets-1.16.5.tar.gz: lib/phoenix_tab_view.dart <==
import 'package:flutter/material.dart';

const defaultPadding = 8.0;

class PhoenixTabView extends StatefulWidget {
  const PhoenixTabView({
    Key? key,
    required this.tabs,
    required this.builder,
    this.currentIndex = 0,
    this.menuBackgroundColor,
    this.menuPadding,
    this.onTabChange,
    this.indicatorColor,
    this.labelColor,
    this.unselectedLabelColor,
    this.labelStyle,
    this.unselectedLabelStyle,
    this.tabController,
  }) : super(key: key);

  final int currentIndex;
  final Map<String, String> tabs;
  final Color? menuBackgroundColor;
  final EdgeInsets? menuPadding;
  final void Function(int index)? onTabChange;
  final Color? indicatorColor;
  final Color? labelColor;
  final Color? unselectedLabelColor;
  final TextStyle? labelStyle;
  final TextStyle? unselectedLabelStyle;
  final Widget Function(BuildContext context, String id) builder;
  final TabController? tabController;

  @override
  State<PhoenixTabView> createState() => _PhoenixTabViewState();
}

class _PhoenixTabViewState extends State<PhoenixTabView>
    with TickerProviderStateMixin {
  TabController? _tabController;
  int _currentIndex = 0;

  @override
  void initState() {
    super.initState();
    if (widget.tabController == null) {
      initTab();
    }
  }

  @override
  void dispose() {
    _tabController?.removeListener(() {});
    super.dispose();
  }

  void initTab() {
    _tabController = TabController(
      length: widget.tabs.keys.length,
      vsync: this,
      initialIndex: widget.currentIndex,
    );
    _tabController?.addListener(() {
      if (widget.onTabChange != null) {
        widget.onTabChange!(_tabController?.index ?? 0);
      }
    });

    setState(() {
      _currentIndex = widget.currentIndex;
    });
  }

  TabController? getTabController() => widget.tabController ?? _tabController;

  @override
  Widget build(BuildContext context) {
    if (widget.tabController == null &&
        widget.tabs.length != _tabController?.length) {
      initTab();
    }

    return DefaultTabController(
      initialIndex: widget.currentIndex,
      length: widget.tabs.length,
      child: Column(
        children: [
          Container(
            color: widget.menuBackgroundColor ?? const Color(0xFFF9F9F9),
            padding:
                widget.menuPadding ?? const EdgeInsets.symmetric(vertical: 16),
            child: TabBar(
              controller: getTabController(),
              onTap: (tabIndex) {},
              isScrollable: true,
              labelPadding: EdgeInsets.zero,
              tabs: widget.tabs.entries
                  .map(
                    (e) => PhoenixTabViewMenuItem(
                      label: e.value,
                      isActive: _currentIndex ==
                          widget.tabs.keys.toList().indexOf(e.key),
                      isFirst: e.key == widget.tabs.keys.first,
                      isLast: e.key == widget.tabs.keys.last,
                    ),
                  )
                  .toList(),
              automaticIndicatorColorAdjustment: false,
              indicatorColor: widget.indicatorColor ?? Colors.transparent,
              labelStyle: widget.labelStyle ??
                  const TextStyle(
                    fontSize: 16,
                    fontWeight: FontWeight.w500,
                  ),
              unselectedLabelStyle: widget.unselectedLabelStyle ??
                  const TextStyle(
                    fontSize: 16,
                    fontWeight: FontWeight.w400,
                  ),
              labelColor: widget.labelColor ?? const Color(0xff67C1BF),
              unselectedLabelColor:
                  widget.unselectedLabelColor ?? const Color(0xff212124),
              padding: EdgeInsets.zero,
            ),
          ),
          Expanded(
            flex: 9,
            child: TabBarView(
              controller: getTabController(),
              children: widget.tabs.entries
                  .map((e) => widget.builder(context, e.key))
                  .toList(),
            ),
          ),
        ],
      ),
    );
  }
}

class PhoenixTabViewMenuItem extends StatefulWidget {
  const PhoenixTabViewMenuItem({
    Key? key,
    this.isFirst = false,
    this.isActive = false,
    this.isLast = false,
    required this.label,
  }) : super(key: key);

  final bool isFirst;
  final bool isLast;
  final bool isActive;
  final String label;

  @override
  State<PhoenixTabViewMenuItem> createState() => _PhoenixTabViewMenuItemState();
}

class _PhoenixTabViewMenuItemState extends State<PhoenixTabViewMenuItem> {
  final GlobalKey _widgetKey = GlobalKey();

  double _leftPadding = defaultPadding;
  double _rightPadding = defaultPadding;

  void _getWidgetInfo(_) {
    final RenderBox renderBox =
        _widgetKey.currentContext?.findRenderObject() as RenderBox;

    final Size size = renderBox.size;
    final deviceWidth = MediaQuery.of(context).size.width;
    final center = deviceWidth * 0.5;

    if (widget.isFirst) {
      _leftPadding += (center - (size.width / 2));
    }

    if (widget.isLast) {
      _rightPadding += (center - (size.width / 2));
    }

    setState(() {});
  }

  @override
  void initState() {
    WidgetsBinding.instance.addPostFrameCallback(_getWidgetInfo);
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      key: _widgetKey,
      padding: EdgeInsets.only(
        left: _leftPadding,
        right: _rightPadding,
      ),
      child: Text(
        widget.label,
      ),
    );
  }
}
